==> gspell-1.1.1.tar.xz: gspell-1.1.1/gspell/gspell-text-view.h <==
/*
 * This file is part of gspell, a spell-checking library.
 *
 * Copyright 2015, 2016 - Sébastien Wilmet
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GSPELL_TEXT_VIEW_H
#define GSPELL_TEXT_VIEW_H

#if !defined (GSPELL_H_INSIDE) && !defined (GSPELL_COMPILATION)
#error "Only <gspell/gspell.h> can be included directly."
#endif

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define GSPELL_TYPE_TEXT_VIEW (gspell_text_view_get_type ())
G_DECLARE_DERIVABLE_TYPE (GspellTextView, gspell_text_view,
			  GSPELL, TEXT_VIEW,
			  GObject)

struct _GspellTextViewClass
{
	GObjectClass parent_class;

	/* Padding for future expansion */
	gpointer padding[8];
};

GspellTextView *	gspell_text_view_get_from_gtk_text_view		(GtkTextView *gtk_view);

GtkTextView *		gspell_text_view_get_view			(GspellTextView *gspell_view);

gboolean		gspell_text_view_get_inline_spell_checking	(GspellTextView *gspell_view);

void			gspell_text_view_set_inline_spell_checking	(GspellTextView *gspell_view,
									 gboolean        enable);

gboolean		gspell_text_view_get_enable_language_menu	(GspellTextView *gspell_view);

void			gspell_text_view_set_enable_language_menu	(GspellTextView *gspell_view,
									 gboolean        enable_language_menu);

G_END_DECLS

#endif /* GSPELL_TEXT_VIEW_H */

/* ex:set ts=8 noet: */

==> gspell-1.12.2.tar.xz: gspell-1.12.2/gspell/gspell-text-view.h <==
/*
 * This file is part of gspell, a spell-checking library.
 *
 * Copyright 2015, 2016 - Sébastien Wilmet
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GSPELL_TEXT_VIEW_H
#define GSPELL_TEXT_VIEW_H

#if !defined (GSPELL_H_INSIDE) && !defined (GSPELL_COMPILATION)
#error "Only <gspell/gspell.h> can be included directly."
#endif

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define GSPELL_TYPE_TEXT_VIEW (gspell_text_view_get_type ())

G_MODULE_EXPORT
G_DECLARE_DERIVABLE_TYPE (GspellTextView, gspell_text_view,
			  GSPELL, TEXT_VIEW,
			  GObject)

struct _GspellTextViewClass
{
	GObjectClass parent_class;

	/* Padding for future expansion */
	gpointer padding[8];
};

G_MODULE_EXPORT
GspellTextView *	gspell_text_view_get_from_gtk_text_view		(GtkTextView *gtk_view);

G_MODULE_EXPORT
void			gspell_text_view_basic_setup			(GspellTextView *gspell_view);

G_MODULE_EXPORT
GtkTextView *		gspell_text_view_get_view			(GspellTextView *gspell_view);

G_MODULE_EXPORT
gboolean		gspell_text_view_get_inline_spell_checking	(GspellTextView *gspell_view);

G_MODULE_EXPORT
void			gspell_text_view_set_inline_spell_checking	(GspellTextView *gspell_view,
									 gboolean        enable);

G_MODULE_EXPORT
gboolean		gspell_text_view_get_enable_language_menu	(GspellTextView *gspell_view);

G_MODULE_EXPORT
void			gspell_text_view_set_enable_language_menu	(GspellTextView *gspell_view,
									 gboolean        enable_language_menu);

G_END_DECLS

#endif /* GSPELL_TEXT_VIEW_H */
